@@ -40,16 +40,16 @@ def draw_walker(test=True, walkers_pool=[], replace=False):
     return model.draw_walker(test, walkers_pool, replace)  # noqa: F821
 
 
-def likelihood(x):
-    """Return a likelihood score using the global model variable."""
+def ln_likelihood(x):
+    """Return ln(likelihood) using the global model variable."""
     global model
-    return model.likelihood(x)  # noqa: F821
+    return model.ln_likelihood(x)  # noqa: F821
 
 
-def prior(x):
-    """Return a prior score using the global model variable."""
+def ln_prior(x):
+    """Return ln(prior) using the global model variable."""
     global model
-    return model.prior(x)  # noqa: F821
+    return model.ln_prior(x)  # noqa: F821
 
 
 def frack(x):
@@ -148,6 +148,7 @@ class Fitter(object):
                    catalogs=[],
                    exit_on_prompt=False,
                    download_recommended_data=False,
+                   local_data_only=False,
                    **kwargs):
         """Fit a list of events with a list of models."""
         global model
@@ -159,6 +160,7 @@ class Fitter(object):
         self._debug = False
         self._speak = speak
         self._download_recommended_data = download_recommended_data
+        self._local_data_only = local_data_only
 
         self._draw_above_likelihood = draw_above_likelihood
 
@@ -261,7 +263,8 @@ class Fitter(object):
         except ValueError:
             pool = SerialPool()
         if pool.is_master():
-            fetched_events = self._fetcher.fetch(event_list)
+            fetched_events = self._fetcher.fetch(
+                event_list, offline=self._offline)
 
             for rank in range(1, pool.size + 1):
                 pool.comm.send(fetched_events, dest=rank, tag=0)
@@ -348,6 +351,9 @@ class Fitter(object):
                         if not success:
                             break
 
+                        if self._local_data_only:
+                            break
+
                         # If our data is missing recommended keys, offer the
                         # user option to pull the missing data from online and
                         # merge with existing data.
@@ -366,7 +372,7 @@ class Fitter(object):
                                 en = (alt_name if alt_name
                                       else self._event_name)
                                 extra_event = self._fetcher.fetch(
-                                    en)[0].get('data')
+                                    en, offline=self._offline)[0].get('data')
 
                                 for rank in range(1, pool.size + 1):
                                     pool.comm.send(extra_event, dest=rank,
@@ -617,7 +623,8 @@ class Fitter(object):
         try:
             if iterations > 0:
                 sampler = MOSSampler(
-                    ntemps, nwalkers, ndim, likelihood, prior, pool=self._pool)
+                    ntemps, nwalkers, ndim, ln_likelihood, ln_prior,
+                    pool=self._pool)
                 st = time.time()
             while (iterations > 0 and (
                     convergence_criteria is not None or ici < len(iter_arr))):
@@ -692,8 +699,8 @@ class Fitter(object):
                                                  tar_x + dxx,
                                                  tar_x - dxx) > 0.0,
                                         tar_x + dxx, tar_x - dxx), 0.0, 1.0)
-                                    new_like = likelihood(new_x)
-                                    new_prob = new_like + prior(new_x)
+                                    new_like = ln_likelihood(new_x)
+                                    new_prob = new_like + ln_prior(new_x)
                                     if new_prob > wprob or np.isnan(wprob):
                                         p[ti][wi] = new_x
                                         lnlike[ti][wi] = new_like
@@ -870,8 +877,8 @@ class Fitter(object):
                         (wi, ti) = tuple(selijs[bhi])
                         if -bh.fun > lnprob[wi][ti]:
                             p[wi][ti] = bh.x
-                            like = likelihood(bh.x)
-                            lnprob[wi][ti] = like + prior(bh.x)
+                            like = ln_likelihood(bh.x)
+                            lnprob[wi][ti] = like + ln_prior(bh.x)
                             lnlike[wi][ti] = like
                     scores = [[-x.fun for x in bhs]]
                     prt.status(
